@@ -236,6 +236,11 @@ def alist_batch_download(
         full_predicate = predicate
     else:
         full_predicate = lambda path: strm_predicate(path) or predicate(path)
+    def onerror(e):
+        if isinstance(e, (FileNotFoundError, NotADirectoryError)):
+            logger and logger.exception("failed to iterdir: %s", e)
+        else:
+            raise e
     if sync:
         seen: dict[str, bool] = {}
         local_local_reldirlen = len(local_dir) + 1
@@ -338,7 +343,7 @@ def alist_batch_download(
                     predicate=full_predicate, 
                     password=password, 
                     refresh=refresh, 
-                    onerror=True, 
+                    onerror=onerror, 
                     async_=True, 
                 ):
                     local_relpath = normpath(path.relative_to(remote_dir))
@@ -426,7 +431,7 @@ def alist_batch_download(
                     predicate=full_predicate, 
                     password=password, 
                     refresh=refresh, 
-                    onerror=True, 
+                    onerror=onerror, 
                 ):
                     local_relpath = normpath(path.relative_to(remote_dir))
                     if local_reldir != (local_reldir := dirname(local_relpath)):
